@@ -24,7 +24,6 @@ const Gio = imports.gi.Gio;
 const Gtk = imports.gi.Gtk;
 const Lang = imports.lang;
 const Mainloop = imports.mainloop;
-const _ = imports.gettext.gettext;
 
 const AccountListBox = imports.accountListBox;
 const Application = imports.application;
@@ -44,7 +43,7 @@ const Response = {
 const CheckInDialog = new Lang.Class({
     Name: 'CheckInDialog',
     Extends: Gtk.Dialog,
-    Template: 'resource:///org/gnome/maps/check-in-dialog.ui',
+    Template: 'resource:///org/gnome/Maps/ui/check-in-dialog.ui',
     InternalChildren: [ 'cancelButton',
                         'okButton',
                         'stack',
